pub enum DeleteOperationKind {
Remove,
SplitBefore,
SplitAfter,
}Expand description
Kind of deletion operation to execute.
Variants
Remove
Remove the files entirely.
SplitBefore
Rewrite the data preserved before the deleted range, then remove the files.
SplitAfter
Rewrite the data preserved after the deleted range, then remove the files.